from analogbridge import *
import os


class Product():
    def __init__(self):
        pass

    @staticmethod
    def list():
        r = APIRequest(url="products", params=None, key_required=False)
        return r.call()


class Customer():
    def __init__(self):
        pass

    @staticmethod
    def find(customer_id):
        r = APIRequest(url="customers/" + customer_id)
        return r.call()

    @staticmethod
    def delete(customer_id):
        r = APIRequest(url="customers/" + customer_id, method="DELETE")
        return r.call()

    @staticmethod
    def create(params=None):
        r = APIRequest(url="customers", method="POST", params=params)
        return r.call()

    @staticmethod
    def update(customer_id, params=None):
        r = APIRequest(url="customers/" + customer_id, method="POST", params=params)
        return r.call()

    @staticmethod
    def list(limit=20, offset=0):
        params = {
            "limit": limit,
            "offset": offset
        }
        r = APIRequest(url="customers", params=params)
        return r.call()


class Order():
    def __init__(self):
        pass

    @staticmethod
    def where(customer_id=None, order_id=None):

        if order_id and customer_id:
            url = os.path.join("customers", customer_id, "orders", order_id)
        elif customer_id:
            url = os.path.join("customers", customer_id, "orders")
        else:
            raise Exception("customer id required")

        r = APIRequest(url=url)
        return r.call()

    @staticmethod
    def import_ready():
        r = APIRequest(url="orders/import-ready")
        return r.call()


# AnalogBridge Python bindings
# API docs at https://analogbridge.io/docs
# Authors:
# Eugene Gekhter <eg@analogbridge.io>

# Configuration variables

api_key = None
api_base = 'https://api.analogbridge.io'
default_api_version = 'v1'
api_version = None

from analogbridge.api_request import APIRequest

from analogbridge.resource import (
    Customer,
    Order,
    Product
)


import analogbridge
import json
from requests import Request, Session


class APIRequest(object):
    def __init__(self, url, method=None, params=None, key_required=True):
        self.url = url
        if not method:
            method = "GET"
        self.method = method
        try:
            self.params = json.dumps(params)
            self.headers = {'Content-Type': 'application/json'}
        except:
            self.params = None
        self.key_required = key_required
        self.resp = None
        self.status_code = None
        self.message = None
        self.data = None
        self.error = None


    def call(self):
        if not analogbridge.api_version:
            analogbridge.api_version = analogbridge.default_api_version

        if self.key_required and not analogbridge.api_key:
            raise Exception("api secret key required")

        s = Session()
        req = Request(self.method, self.build_url(), headers=self.headers, data=self.params,
                      auth=(analogbridge.api_key, ''))
        prepped = req.prepare()
        self.resp = s.send(prepped)

        self.handle_response()

        return self.data


    def build_url(self):
        return analogbridge.api_base + "/" + analogbridge.api_version + "/" + self.url

    def handle_response(self):
        self.status_code = self.resp.status_code

        if self.status_code < 200 or self.status_code >= 300:
            self.error = True
            self.message = self.resp.json()
            raise Exception(self.message)
        else:
            self.message = self.resp.json()['message'] if 'message' in self.resp.json() else None
            self.data = self.resp.json()['data'] if 'data' in self.resp.json() else self.resp.json()

        return self.data


import os
import sys

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

try:
    from distutils.command.build_py import build_py_2to3 as build_py
except ImportError:
    from distutils.command.build_py import build_py

install_requires = ['requests >= 0.8.8']

setup(
    name='analogbridge',
    cmdclass={'build_py': build_py},
    version='0.1',
    description='Analog Bridge Python bindings',
    long_description='Enable users to import any analog media format directly into your app with the Analog Bridge API',
    author='Eugene Gekhter',
    author_email='support@analogbridge.io',
    url='https://github.com/analogbridge/analog-bridge-python',
    packages=['analogbridge'],
    install_requires=install_requires,
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ])
